==> qt6-webengine_6.8.3+dfsg.orig.tar.xz: qtwebengine-everywhere-src-6.8.3/src/3rdparty/chromium/base/task/task_features.h <==
// Copyright 2018 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef BASE_TASK_TASK_FEATURES_H_
#define BASE_TASK_TASK_FEATURES_H_

#include "base/base_export.h"
#include "base/feature_list.h"
#include "base/metrics/field_trial_params.h"
#include "build/build_config.h"

namespace base {

// Fixed amount of threads that will be used as a cap for thread pools.
BASE_EXPORT BASE_DECLARE_FEATURE(kThreadPoolCap2);

extern const BASE_EXPORT base::FeatureParam<int> kThreadPoolCapRestrictedCount;

// Under this feature, a utility_thread_group will be created for
// running USER_VISIBLE tasks.
BASE_EXPORT BASE_DECLARE_FEATURE(kUseUtilityThreadGroup);

// Under this feature, worker threads are not reclaimed after a timeout. Rather,
// only excess workers are cleaned up immediately after finishing a task.
BASE_EXPORT BASE_DECLARE_FEATURE(kNoWorkerThreadReclaim);

// This feature controls whether ThreadPool WorkerThreads should hold off waking
// up to purge partition alloc within the first minute of their lifetime. See
// base::internal::GetSleepTimeBeforePurge.
BASE_EXPORT BASE_DECLARE_FEATURE(kDelayFirstWorkerWake);

// Under this feature, a non-zero leeway is added to delayed tasks. Along with
// DelayPolicy, this affects the time at which a delayed task runs.
BASE_EXPORT BASE_DECLARE_FEATURE(kAddTaskLeewayFeature);
#if BUILDFLAG(IS_WIN)
constexpr TimeDelta kDefaultLeeway = Milliseconds(16);
#else
constexpr TimeDelta kDefaultLeeway = Milliseconds(8);
#endif  // #if !BUILDFLAG(IS_WIN)
extern const BASE_EXPORT base::FeatureParam<TimeDelta> kTaskLeewayParam;

// We consider that delayed tasks above |kMaxPreciseDelay| never need
// DelayPolicy::kPrecise. The default value is slightly above 30Hz timer.
constexpr TimeDelta kDefaultMaxPreciseDelay = Milliseconds(36);
extern const BASE_EXPORT base::FeatureParam<TimeDelta> kMaxPreciseDelay;

// Under this feature, wake ups are aligned at a 8ms boundary when allowed per
// DelayPolicy.
BASE_EXPORT BASE_DECLARE_FEATURE(kAlignWakeUps);

// Under this feature, slack is added on mac message pumps that support it when
// allowed per DelayPolicy.
BASE_EXPORT BASE_DECLARE_FEATURE(kTimerSlackMac);

// Under this feature, tasks that need high resolution timer are determined
// based on explicit DelayPolicy rather than based on a threshold.
BASE_EXPORT BASE_DECLARE_FEATURE(kExplicitHighResolutionTimerWin);

// Feature to run tasks by batches before pumping out messages.
BASE_EXPORT BASE_DECLARE_FEATURE(kRunTasksByBatches);

// Controls the max number of delayed tasks that can run before selecting an
// immediate task in sequence manager.
BASE_EXPORT BASE_DECLARE_FEATURE(kMaxDelayedStarvationTasks);
extern const BASE_EXPORT base::FeatureParam<int>
    kMaxDelayedStarvationTasksParam;

// Feature to use a JobTaskSource implementation that minimizes lock contention.
BASE_EXPORT BASE_DECLARE_FEATURE(kUseNewJobImplementation);

}  // namespace base

#endif  // BASE_TASK_TASK_FEATURES_H_

==> qt6-webengine_6.9.2+dfsg.orig.tar.xz: qtwebengine-everywhere-src-6.9.2/src/3rdparty/chromium/base/task/task_features.h <==
// Copyright 2018 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef BASE_TASK_TASK_FEATURES_H_
#define BASE_TASK_TASK_FEATURES_H_

#include "base/base_export.h"
#include "base/feature_list.h"
#include "base/metrics/field_trial_params.h"
#include "build/build_config.h"

namespace base {

// Fixed amount of threads that will be used as a cap for thread pools.
BASE_EXPORT BASE_DECLARE_FEATURE(kThreadPoolCap2);

extern const BASE_EXPORT base::FeatureParam<int> kThreadPoolCapRestrictedCount;

// Under this feature, a utility_thread_group will be created for
// running USER_VISIBLE tasks.
BASE_EXPORT BASE_DECLARE_FEATURE(kUseUtilityThreadGroup);

// Under this feature, worker threads are not reclaimed after a timeout. Rather,
// only excess workers are cleaned up immediately after finishing a task.
BASE_EXPORT BASE_DECLARE_FEATURE(kNoWorkerThreadReclaim);

// This feature controls whether ThreadPool WorkerThreads should hold off waking
// up to purge PartitionAlloc within the first minute of their lifetime. See
// base::internal::GetSleepDurationBeforePurge.
BASE_EXPORT BASE_DECLARE_FEATURE(kDelayFirstWorkerWake);

// Under this feature, a non-zero leeway is added to delayed tasks. Along with
// DelayPolicy, this affects the time at which a delayed task runs.
BASE_EXPORT BASE_DECLARE_FEATURE(kAddTaskLeewayFeature);
#if BUILDFLAG(IS_WIN)
constexpr TimeDelta kDefaultLeeway = Milliseconds(16);
#else
constexpr TimeDelta kDefaultLeeway = Milliseconds(8);
#endif  // #if !BUILDFLAG(IS_WIN)
extern const BASE_EXPORT base::FeatureParam<TimeDelta> kTaskLeewayParam;

// We consider that delayed tasks above |kMaxPreciseDelay| never need
// DelayPolicy::kPrecise. The default value is slightly above 30Hz timer.
constexpr TimeDelta kDefaultMaxPreciseDelay = Milliseconds(36);
extern const BASE_EXPORT base::FeatureParam<TimeDelta> kMaxPreciseDelay;

// Under this feature, wake ups are aligned at a 8ms boundary when allowed per
// DelayPolicy.
BASE_EXPORT BASE_DECLARE_FEATURE(kAlignWakeUps);

// Under this feature, slack is added on mac message pumps that support it when
// allowed per DelayPolicy.
BASE_EXPORT BASE_DECLARE_FEATURE(kTimerSlackMac);

// Under this feature, tasks that need high resolution timer are determined
// based on explicit DelayPolicy rather than based on a threshold.
BASE_EXPORT BASE_DECLARE_FEATURE(kExplicitHighResolutionTimerWin);

// Under this feature, the Windows UI pump uses a WaitableEvent to wake itself
// up when not in a native nested loop. It also uses different control flow,
// calling Win32 MessagePump functions less often.
BASE_EXPORT BASE_DECLARE_FEATURE(kUIPumpImprovementsWin);

// Under this feature, the Android pump will call ALooper_PollOnce() rather than
// unconditionally yielding to native to determine whether there exists native
// work to be done before sleep.
BASE_EXPORT BASE_DECLARE_FEATURE(kPumpFastToSleepAndroid);

// Feature to run tasks by batches before pumping out messages.
BASE_EXPORT BASE_DECLARE_FEATURE(kRunTasksByBatches);

// Feature to use ThreadGroupSemaphore instead of ThreadGroupImpl.
BASE_EXPORT BASE_DECLARE_FEATURE(kThreadGroupSemaphore);
extern const BASE_EXPORT base::FeatureParam<int> kMaxNumWorkersCreated;

}  // namespace base

#endif  // BASE_TASK_TASK_FEATURES_H_
